@@ -55,7 +55,7 @@ my $output_fh
 : $out_fh
 ;
 
-#mkdir_if( search_bin( 't' ),  'sandbox' );
+mkdir_if( search_bin( 't' ),  'sandbox' );
 
 ########################################################################
 # exported utilities
