@@ -1,6 +1,6 @@
 package Bar;
 our VERSION='1.234567';
-no v5.999999;
+no 5.008.008;
 1
 __END__
 
