@@ -1,6 +1,6 @@
 package Foo;
 our VERSION='1.234567';
-use v5.000.001;
+use 5.888_888;
 1
 __END__
 
